@@ -3,15 +3,15 @@ test_that("attributes_means", {
   model <- lm(Sepal.Length ~ Species * Sepal.Width, data = iris)
 
   estim <- suppressMessages(estimate_means(model))
-  expect_identical(attributes(estim)$at, "Species")
-  expect_identical(attributes(estim)$fixed, NULL)
+  expect_identical(attributes(estim)$by, "Species")
+  expect_null(attributes(estim)$fixed)
 
   estim <- suppressMessages(estimate_means(model, fixed = "Sepal.Width"))
-  expect_identical(attributes(estim)$at, "Species")
+  expect_identical(attributes(estim)$by, "Species")
   expect_identical(attributes(estim)$fixed, "Sepal.Width")
 
-  estim <- suppressMessages(estimate_means(model, at = "all"))
-  expect_identical(attributes(estim)$at, c("Species", "Sepal.Width"))
+  estim <- suppressMessages(estimate_means(model, by = "all"))
+  expect_identical(attributes(estim)$by, c("Species", "Sepal.Width"))
 })
 
 
@@ -22,13 +22,13 @@ test_that("attributes_contrasts", {
 
   estim <- suppressMessages(estimate_contrasts(model))
   expect_identical(attributes(estim)$contrast, "Species")
-  expect_identical(attributes(estim)$at, NULL)
-  expect_identical(attributes(estim)$fixed, NULL)
+  expect_null(attributes(estim)$by)
+  expect_null(attributes(estim)$fixed)
 
   estim <- suppressMessages(estimate_contrasts(model, fixed = "Sepal.Width"))
   expect_identical(attributes(estim)$contrast, "Species")
   expect_identical(attributes(estim)$fixed, "Sepal.Width")
-  expect_identical(attributes(estim)$modulate, NULL)
+  expect_null(attributes(estim)$modulate)
 })
 
 
