@@ -28,20 +28,20 @@ test_that("estimate_means - glmmTMB", {
 
 test_that("estimate_contrasts - glmmTMB", {
   estim <- suppressMessages(estimate_contrasts(model))
-  expect_equal(dim(estim), c(1, 9))
+  expect_identical(dim(estim), c(1L, 9L))
   expect_equal(estim$Difference, -1.141923, tolerance = 1e-1)
-  expect_equal(c(estim$Level1[1], estim$Level2[1]), c("yes", "no"))
+  expect_identical(c(estim$Level1[1], estim$Level2[1]), c("yes", "no"))
 
   estim <- suppressMessages(estimate_contrasts(model, component = "zi"))
-  expect_equal(dim(estim), c(1, 9))
+  expect_identical(dim(estim), c(1L, 9L))
   expect_equal(estim$Difference, 1.736067, tolerance = 1e-1)
-  expect_equal(c(estim$Level1[1], estim$Level2[1]), c("yes", "no"))
+  expect_identical(c(estim$Level1[1], estim$Level2[1]), c("yes", "no"))
 })
 
 test_that("estimate_slope - glmmTMB", {
   estim <- suppressMessages(estimate_slopes(model2,
     trend = "cover",
-    at = "mined", regrid = "response"
+    by = "mined", regrid = "response"
   ))
   estim2 <- as.data.frame(emmeans::emtrends(model2, "mined", var = "cover", regrid = "response"))
   expect_equal(estim$Coefficient, estim2$cover.trend, tolerance = 1e-2)
@@ -50,15 +50,15 @@ test_that("estimate_slope - glmmTMB", {
 
 test_that("estimate_response - glmmTMB", {
   estim <- suppressMessages(estimate_expectation(model2))
-  expect_equal(dim(estim), c(nrow(data), 8))
+  expect_identical(dim(estim), c(nrow(data), 8L))
 })
 
 test_that("estimate_link - glmmTMB", {
   estim <- suppressMessages(estimate_link(model2, preserve_range = FALSE))
-  expect_equal(dim(estim), c(20, 7))
+  expect_identical(dim(estim), c(20L, 7L))
 })
 
 test_that("estimate_response - glmmTMB", {
   estim <- suppressMessages(estimate_expectation(model2))
-  expect_equal(dim(estim), c(644, 8))
+  expect_identical(dim(estim), c(644L, 8L))
 })
